@@ -2,12 +2,17 @@
 #   MADE BY: ARMANDO CHAPARRO   #
 #################################
 
+import sys
+
+sys.dont_write_bytecode = True
+
 from pylejandria import gui
-from pylejandria import help
 from pylejandria import math
 from pylejandria import module
 from pylejandria import tools
 from pylejandria import upload
+from pylejandria import constants
+# from pylejandria import auto
 
 MAFER = """
 It´s hard to forget
